import asyncio
import os
import re
import textwrap
from typing import List, Optional, TypeVar

import toml

T = TypeVar("T")


def generate_resource_name(resource: str, account: str, id: str):
    return f"accounts/{account}/{resource}/{id}"


def generate_model_resource_name(account: str, id: str):
    return generate_resource_name("models", account, id)


def is_valid_resource_name(name: str):
    """
    Fireworks only allows lowercase alphanumeric characters and hyphens in its resource name
    """
    return re.match(r"^[a-z0-9-]+$", name)


def make_valid_resource_name(name: str):
    """
    Fireworks only allows lowercase alphanumeric characters and hyphens in its resource name
    """
    return re.sub(r"[^a-z0-9-]", "-", name)


def find_requirements_or_pyproject(file_path: Optional[str]):
    """
    Iteratively find the requirements.txt or pyproject.toml file in the directory tree.
    """
    while file_path:
        if os.path.exists(os.path.join(file_path, "requirements.txt")):
            return os.path.join(file_path, "requirements.txt")
        if os.path.exists(os.path.join(file_path, "pyproject.toml")):
            return os.path.join(file_path, "pyproject.toml")
        file_path = os.path.dirname(file_path)
    return None


def get_requirements_from_pyproject_or_requirements_txt(file_path: Optional[str]) -> Optional[str]:
    if file_path is None:
        return None
    if file_path.endswith("pyproject.toml"):
        return convert_pyproject_dependencies_to_requirements_txt(get_requirements_from_pyproject(file_path))
    if file_path.endswith("requirements.txt"):
        return open(file_path).read()


def get_requirements_from_pyproject(pyproject_path: str) -> List[str]:
    with open(pyproject_path, "r") as f:
        pyproject = toml.loads(f.read())
    return pyproject["project"]["dependencies"]


def convert_pyproject_dependencies_to_requirements_txt(dependencies: List[str]):
    return "\n".join(dependencies)


def dedent_code(code: str) -> str:
    """
    Remove leading whitespace from code while preserving relative indentation.

    Args:
        code: The indented code string

    Returns:
        Code string with leading whitespace removed but relative indentation preserved

    Example:
        >>> code = '''
        ...     @reward_function
        ...     def evaluate(messages):
        ...         return {"score": 1.0, "reason": "test"}
        ... '''
        >>> print(dedent_code(code))
        @reward_function
        def evaluate(messages):
            return {"score": 1.0, "reason": "test"}
    """
    return textwrap.dedent(code).strip()


def generate_time_str(minutes: int, seconds: int) -> str:
    if minutes == 0:
        return f"{seconds}s"
    return f"{minutes}m{seconds}s"


def get_api_key_from_env() -> Optional[str]:
    """
    Attempts to obtain API key from the environment variable.

    Returns:
        API key retrieved from env variable or None if missing.
    """
    return os.environ.get("FIREWORKS_API_KEY")


def is_running_in_async_context() -> bool:
    """
    Check if the current code is running in an async context with a running event loop.

    Returns:
        True if running in an async context, False otherwise.

    Example:
        >>> if is_running_in_async_context():
        ...     # We're in an async function or callback
        ...     pass
        ... else:
        ...     # We're in a sync context
        ...     pass
    """
    try:
        asyncio.get_running_loop()
        return True
    except RuntimeError:
        # No running event loop - we're in a sync context
        return False



from typing import (
    AsyncGenerator,
    Generator,
    Iterable,
    List,
    Literal,
    Optional,
    Union,
    overload,
    TYPE_CHECKING,
)

from fireworks.llm._types import ResponseFormat
from openai import NotGiven, NOT_GIVEN
from openai.types.chat.chat_completion import ChatCompletion as OpenAIChatCompletion
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.chat_completion_message_param import ChatCompletionMessageParam
from openai.types.chat.chat_completion_tool_param import ChatCompletionToolParam

from fireworks.client.chat_completion import ChatCompletionV2 as FireworksChatCompletion
from fireworks._literals import ReasoningEffort
from fireworks.llm.base_completion import BaseCompletion

# Type checking imports to avoid circular imports
if TYPE_CHECKING:
    from fireworks.llm.llm import LLM


class ChatCompletion(BaseCompletion):
    def __init__(self, llm: "LLM"):
        super().__init__(llm)
        self._client = FireworksChatCompletion(llm._client)

    @overload
    def create(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: Literal[False] = False,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> OpenAIChatCompletion:
        pass

    @overload
    def create(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: Literal[True] = True,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> Generator[ChatCompletionChunk, None, None]:
        pass

    def _build_request_params(
        self,
        model_id: str,
        messages: Iterable[ChatCompletionMessageParam],
        stream: bool = False,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> dict:
        """Build request parameters for chat completion calls."""
        # Build common parameters using base class method
        params = self._build_common_request_params(
            model_id=model_id,
            stream=stream,
            max_tokens=max_tokens,
            temperature=temperature,
            top_p=top_p,
            top_k=top_k,
            frequency_penalty=frequency_penalty,
            presence_penalty=presence_penalty,
            repetition_penalty=repetition_penalty,
            reasoning_effort=reasoning_effort,
            mirostat_lr=mirostat_lr,
            mirostat_target=mirostat_target,
            n=n,
            ignore_eos=ignore_eos,
            stop=stop,
            response_format=response_format,
            context_length_exceeded_behavior=context_length_exceeded_behavior,
            user=user,
            perf_metrics_in_response=perf_metrics_in_response,
            extra_headers=extra_headers,
            **kwargs,
        )

        # Add chat completion-specific parameters
        params["messages"] = messages

        # Add optional chat completion-specific parameters if not None
        if prompt_truncate_len is not None:
            params["prompt_truncate_len"] = prompt_truncate_len

        # Only include tools if it's not NotGiven
        if not isinstance(tools, NotGiven):
            params["tools"] = tools

        return params

    def create(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: bool = False,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> Union[OpenAIChatCompletion, Generator[ChatCompletionChunk, None, None]]:
        if "model" in kwargs:
            raise ValueError(
                "Pass model as a parameter to the constructor of LLM instead of passing it as a parameter to the create method"
            )
        model_id = self._llm.model_id()
        params = self._build_request_params(
            model_id,
            messages,
            stream,
            response_format,
            reasoning_effort,
            max_tokens,
            prompt_truncate_len,
            temperature,
            top_p,
            top_k,
            frequency_penalty,
            presence_penalty,
            repetition_penalty,
            mirostat_lr,
            mirostat_target,
            n,
            ignore_eos,
            stop,
            context_length_exceeded_behavior,
            user,
            tools,
            perf_metrics_in_response,
            extra_headers,
            **kwargs,
        )

        return self._execute_with_retry(params, stream, "chat completion")

    @overload
    async def acreate(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: Literal[False] = False,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> OpenAIChatCompletion: ...

    @overload
    async def acreate(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: Literal[True] = True,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> AsyncGenerator[ChatCompletionChunk, None]:
        pass

    async def acreate(
        self,
        messages: Iterable[ChatCompletionMessageParam],
        stream: bool = False,
        response_format: Optional[ResponseFormat] = None,
        reasoning_effort: Optional[ReasoningEffort] = None,
        max_tokens: Optional[int] = None,
        prompt_truncate_len: Optional[int] = None,
        temperature: Optional[float] = None,
        top_p: Optional[float] = None,
        top_k: Optional[int] = None,
        frequency_penalty: Optional[float] = None,
        presence_penalty: Optional[float] = None,
        repetition_penalty: Optional[float] = None,
        mirostat_lr: Optional[float] = None,
        mirostat_target: Optional[float] = None,
        n: Optional[int] = None,
        ignore_eos: Optional[bool] = None,
        stop: Optional[Union[str, List[str]]] = None,
        context_length_exceeded_behavior: Optional[str] = None,
        user: Optional[str] = None,
        tools: Union[List[ChatCompletionToolParam], NotGiven] = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] = None,
        extra_headers=None,
        **kwargs,
    ) -> Union[OpenAIChatCompletion, AsyncGenerator[ChatCompletionChunk, None]]:
        if "model" in kwargs:
            raise ValueError(
                "Pass model as a parameter to the constructor of LLM instead of passing it as a parameter to the create method"
            )
        model_id = self._llm.model_id()
        params = self._build_request_params(
            model_id,
            messages,
            stream,
            response_format,
            reasoning_effort,
            max_tokens,
            prompt_truncate_len,
            temperature,
            top_p,
            top_k,
            frequency_penalty,
            presence_penalty,
            repetition_penalty,
            mirostat_lr,
            mirostat_target,
            n,
            ignore_eos,
            stop,
            context_length_exceeded_behavior,
            user,
            tools,
            perf_metrics_in_response,
            extra_headers,
            **kwargs,
        )

        return await self._execute_with_retry_async(params, stream, "chat completion")


class Chat:
    def __init__(self, llm: "LLM", model):
        self.completions = ChatCompletion(llm)



from collections import defaultdict, deque
from typing import Optional


class Metrics:
    """
    A class for tracking and analyzing performance metrics for LLM operations.

    This class maintains a rolling window of metrics such as response times,
    token generation speeds, and other performance indicators. It provides
    statistical methods to analyze these metrics (mean, median, min, max).

    Each metric is stored as a list of values with a maximum size to prevent
    unbounded memory growth. When the maximum size is reached, the oldest
    values are removed in a FIFO manner.
    """

    def __init__(self, max_metrics: int = 1000):
        """
        Initialize the metrics tracker.

        Args:
            max_metrics: Maximum number of values to store for each metric.
                         Defaults to 1000. When exceeded, oldest values are removed.
        """
        self._metrics = defaultdict(deque)
        self._max_metrics = max_metrics

    def add_metric(self, metric_name: str, metric_value: float):
        """
        Add a new metric value to the specified metric.

        Args:
            metric_name: Name of the metric to track
            metric_value: Value to add to the metric
        """
        self._metrics[metric_name].append(metric_value)
        if len(self._metrics[metric_name]) > self._max_metrics:
            self._metrics[metric_name].popleft()

    def get_metric(self, metric_name: str):
        """
        Get all recorded values for a specific metric.

        Args:
            metric_name: Name of the metric to retrieve

        Returns:
            List of metric values or None if the metric doesn't exist
        """
        if metric_name not in self._metrics:
            return None
        return self._metrics[metric_name]

    def get_metric_mean(self, metric_name: str) -> Optional[float]:
        """
        Calculate the arithmetic mean of a metric's values.

        Args:
            metric_name: Name of the metric

        Returns:
            Mean value or None if the metric doesn't exist
        """
        if metric_name not in self._metrics:
            return None
        return sum(self._metrics[metric_name]) / len(self._metrics[metric_name])

    def get_metric_median(self, metric_name: str):
        """
        Calculate the median value of a metric.

        Args:
            metric_name: Name of the metric

        Returns:
            Median value or None if the metric doesn't exist
        """
        if metric_name not in self._metrics:
            return None
        return sorted(self._metrics[metric_name])[len(self._metrics[metric_name]) // 2]

    def get_metric_min(self, metric_name: str):
        """
        Get the minimum value recorded for a metric.

        Args:
            metric_name: Name of the metric

        Returns:
            Minimum value or None if the metric doesn't exist
        """
        if metric_name not in self._metrics:
            return None
        return min(self._metrics[metric_name])

    def get_metric_max(self, metric_name: str):
        """
        Get the maximum value recorded for a metric.

        Args:
            metric_name: Name of the metric

        Returns:
            Maximum value or None if the metric doesn't exist
        """
        if metric_name not in self._metrics:
            return None
        return max(self._metrics[metric_name])



from .llm import LLM
from .dataset import Dataset
from .evaluator import Evaluator
from .supervised_fine_tuning_job import SupervisedFineTuningJob
from .batch_inference_job import BatchInferenceJob
import importlib.metadata
from typing import Callable, NoReturn, Protocol, TypeVar, cast

F = TypeVar("F", bound=Callable[..., object])

class _RewardFunctionDecorator(Protocol):
    def __call__(
        self,
        _func: F | None = None,
        *,
        mode: str = "pointwise",
        id: str | None = None,
        requirements: list[str] | None = None,
    ) -> F | Callable[[F], F]:
        ...

try:
    from reward_kit import reward_function as _reward_function  # type: ignore
    reward_function: _RewardFunctionDecorator = cast(_RewardFunctionDecorator, _reward_function)
except Exception:  # pragma: no cover
    def _reward_function_stub(*args: object, **kwargs: object) -> NoReturn:
        raise ImportError(
            "reward_kit is not installed. Install the extra: `pip install 'fireworks-ai[reward-kit]'` or with uv: `uv pip install 'fireworks-ai[reward-kit]'`."
        )

    reward_function: _RewardFunctionDecorator = cast(_RewardFunctionDecorator, _reward_function_stub)
from openai.types.chat.chat_completion import ChatCompletion
from openai.types.chat.chat_completion_chunk import ChatCompletionChunk
from openai.types.chat.chat_completion_message_param import ChatCompletionMessageParam
from openai.types.chat.chat_completion_tool_param import ChatCompletionToolParam
from .platform import FireworksPlatform
import fireworks.control_plane.generated.protos.gateway as fw
from fireworks._literals import (
    DeploymentTypeLiteral,
    RegionLiteral,
    MultiRegionLiteral,
    AcceleratorTypeLiteral,
    PrecisionLiteral,
    DirectRouteTypeLiteral,
    ReasoningEffort,
)

try:
    __version__ = importlib.metadata.version("fireworks-ai")
except importlib.metadata.PackageNotFoundError:
    __version__ = "0.0.0"  # Fallback for development mode

__all__ = [
    "LLM",
    "Dataset",
    "Evaluator",
    "SupervisedFineTuningJob",
    "BatchInferenceJob",
    "FireworksPlatform",
    "fw",
    "__version__",
    "reward_function",
    "ChatCompletion",
    "ChatCompletionChunk",
    "ChatCompletionMessageParam",
    "ChatCompletionToolParam",
    "DeploymentTypeLiteral",
    "RegionLiteral",
    "MultiRegionLiteral",
    "AcceleratorTypeLiteral",
    "PrecisionLiteral",
    "DirectRouteTypeLiteral",
    "ReasoningEffort",
]



from typing_extensions import Literal, Required, TypedDict, Union
from openai.types.chat.completion_create_params import ResponseFormat as OpenAIResponseFormat


class ResponseFormatGrammar(TypedDict, total=False):
    type: Required[Literal["grammar"]]
    """The type of response format being defined. Always `text`."""

    grammar: str
    """See https://fireworks.ai/docs/structured-responses/structured-output-grammar-based"""


ResponseFormat = Union[OpenAIResponseFormat, ResponseFormatGrammar]


class WandbConfigParam(TypedDict, total=True):
    """
    Configuration for Weights & Biases (wandb) integration with fine-tuning jobs.

    You must provide ALL three required fields (api_key, project, entity) for wandb logging
    to work properly. Partial configurations will not enable wandb logging.

    Usage Patterns:

    1. **No wandb logging** (default):
       ```python
       wandb_config = None  # No wandb integration
       ```

    2. **Complete configuration** (all three fields required):
       ```python
       wandb_config = {
           "api_key": "your-api-key",
           "project": "your-project",
           "entity": "your-entity"
       }
       ```

    Backend Behavior:
    - Wandb logging is enabled only when ALL three required fields (api_key, project, entity) are present
    - Partial configurations (missing any of the three fields) will NOT enable wandb logging
    - The system automatically generates run IDs and URLs
    - Empty strings are treated as missing fields
    """

    api_key: str
    """
    Weights & Biases API key for authentication.
    
    - If provided: Use this API key for the job
    - If not provided: Wandb logging will be disabled
    
    The API key is automatically encrypted and stored securely.
    """

    project: str
    """
    Weights & Biases project name where metrics will be logged.
    
    - If provided: Use this project for the job
    - If not provided: Wandb logging will be disabled
    
    The project must exist in your wandb account or be created automatically.
    """

    entity: str
    """
    Weights & Biases entity (username or team name).
    
    - If provided: Use this entity for the job
    - If not provided: Wandb logging will be disabled
    
    This can be your personal username or a team/organization name.
    """



import asyncio
import time
from typing import TYPE_CHECKING, Optional, Union, List
from openai import NotGiven, NOT_GIVEN
from abc import ABC, abstractmethod

from fireworks._literals import ReasoningEffort
from fireworks.client.error import (
    InvalidRequestError,
    RateLimitError,
    BadGatewayError,
    ServiceUnavailableError,
)
from fireworks._logger import logger
from fireworks.llm._types import ResponseFormat

# Type checking imports to avoid circular imports
if TYPE_CHECKING:
    from fireworks.llm.llm import LLM

DEFAULT_MAX_RETRIES = 10
DEFAULT_DELAY = 0.5


class BaseCompletion(ABC):
    """Base class for completion wrappers that provides common functionality."""

    _client = None  # type: ignore

    def __init__(self, llm: "LLM"):
        self._model_id = None
        self._llm = llm

    def _create_setup(self, skip_setup: bool = False):
        """
        Setup for .create() and .acreate()

        Args:
            skip_setup: If True, skip deployment readiness check and model ID resolution
        """
        if skip_setup:
            # Return cached model_id if available, otherwise get it without setup
            return self._llm.model_id()
        if not self._llm._ran_setup:
            self._llm._ensure_deployment_ready()
            self._llm._ran_setup = True
        return self._llm.model_id()

    def _should_retry_error(self, e: Exception) -> bool:
        """Check if an error should trigger a retry."""
        if isinstance(e, InvalidRequestError):
            error_msg = str(e).lower()
            return any(
                msg in error_msg
                for msg in [
                    "model not found, inaccessible, and/or not deployed",
                    "model does not exist",
                ]
            )
        return isinstance(e, (BadGatewayError, ServiceUnavailableError, RateLimitError))

    @property
    def client(self):  # type: ignore
        return self._client

    def _execute_with_retry(self, params: dict, stream: bool | NotGiven, operation_name: str):
        metric = self._llm.enable_metrics and not stream
        return self._retry_with_backoff(
            self.client.create, **params, operation_name=operation_name, metric=metric
        )  # type: ignore

    async def _execute_with_retry_async(self, params: dict, stream: bool | NotGiven, operation_name: str):
        metric = self._llm.enable_metrics and not stream
        return await self._retry_with_backoff_async(
            self.client.acreate, **params, operation_name=operation_name, metric=metric
        )  # type: ignore

    def _build_common_request_params(
        self,
        model_id: str,
        stream: Optional[bool] | NotGiven = NOT_GIVEN,
        max_tokens: Optional[int] | NotGiven = NOT_GIVEN,
        temperature: Optional[float] | NotGiven = NOT_GIVEN,
        top_p: Optional[float] | NotGiven = NOT_GIVEN,
        top_k: Optional[int] | NotGiven = NOT_GIVEN,
        frequency_penalty: Optional[float] | NotGiven = NOT_GIVEN,
        presence_penalty: Optional[float] | NotGiven = NOT_GIVEN,
        repetition_penalty: Optional[float] | NotGiven = NOT_GIVEN,
        reasoning_effort: Optional[ReasoningEffort] | NotGiven = NOT_GIVEN,
        mirostat_lr: Optional[float] | NotGiven = NOT_GIVEN,
        mirostat_target: Optional[float] | NotGiven = NOT_GIVEN,
        n: Optional[int] | NotGiven = NOT_GIVEN,
        ignore_eos: Optional[bool] | NotGiven = NOT_GIVEN,
        stop: Optional[Union[str, List[str]]] | NotGiven = NOT_GIVEN,
        response_format: Optional[ResponseFormat] | NotGiven = NOT_GIVEN,
        context_length_exceeded_behavior: Optional[str] | NotGiven = NOT_GIVEN,
        user: Optional[str] | NotGiven = NOT_GIVEN,
        perf_metrics_in_response: Optional[bool] | NotGiven = NOT_GIVEN,
        extra_headers=None,
        **kwargs,
    ) -> dict:
        """Build common request parameters shared by both completion types."""
        # Start with required parameters and those that have default handling
        params = {
            "model": model_id,
            **kwargs,
        }

        # Only add optional parameters if they are not NOT_GIVEN
        optional_params = {
            "stream": stream,
            "temperature": temperature,
            "extra_headers": extra_headers,
            "max_tokens": max_tokens,
            "top_p": top_p,
            "top_k": top_k,
            "frequency_penalty": frequency_penalty,
            "presence_penalty": presence_penalty,
            "repetition_penalty": repetition_penalty,
            "reasoning_effort": reasoning_effort,
            "mirostat_lr": mirostat_lr,
            "mirostat_target": mirostat_target,
            "n": n,
            "ignore_eos": ignore_eos,
            "stop": stop,
            "response_format": response_format,
            "context_length_exceeded_behavior": context_length_exceeded_behavior,
            "user": user,
            "perf_metrics_in_response": perf_metrics_in_response,
        }

        # Add only non-NOT_GIVEN optional parameters
        for key, value in optional_params.items():
            if value is not NOT_GIVEN and value is not None:
                params[key] = value

        return params

    @abstractmethod
    def _build_request_params(self, model_id: str, *args, **kwargs) -> dict:
        """Build request parameters - must be implemented by subclasses."""
        pass

    def _retry_with_backoff(
        self,
        func,
        *args,
        operation_name: str = "operation",
        metric: bool = False,
        **kwargs,
    ):
        """DRY helper for retrying sync functions with backoff and optional metrics."""
        retries = 0
        delay = DEFAULT_DELAY
        while retries < self._llm.max_retries:
            try:
                if metric:
                    start_time = time.time()
                result = func(*args, **kwargs)
                if metric:
                    end_time = time.time()
                    self._llm._metrics.add_metric("time_to_last_token", end_time - start_time)
                return result
            except Exception as e:
                if not self._should_retry_error(e):
                    raise e
                logger.debug(f"{type(e).__name__}: {e}. operation: {operation_name}")
                time.sleep(delay)
                retries += 1
                delay *= 2
        raise Exception(f"Failed to create {operation_name} after {self._llm.max_retries} retries")

    async def _retry_with_backoff_async(
        self,
        func,
        *args,
        operation_name: str = "operation",
        metric: bool = False,
        **kwargs,
    ):
        """DRY helper for retrying async functions with backoff and optional metrics."""
        retries = 0
        delay = DEFAULT_DELAY
        while retries <= self._llm.max_retries:
            try:
                if metric:
                    start_time = time.time()
                result = func(*args, **kwargs)
                if kwargs.get("stream", False):
                    if operation_name == "responses":
                        return await result
                    else:
                        return result  # Return generator directly for streaming
                elif metric:
                    result = await result
                    end_time = time.time()
                    self._llm._metrics.add_metric("time_to_last_token", end_time - start_time)
                else:
                    result = await result
                return result
            except Exception as e:
                if not self._should_retry_error(e):
                    raise e
                logger.debug(f"{type(e).__name__}: {e}. operation: {operation_name}")
                await asyncio.sleep(delay)
                retries += 1
                delay *= 2
        raise Exception(f"Failed to create {operation_name} after {self._llm.max_retries} retries")



from ..buf.validate import validate_pb2 as _validate_pb2
from . import options_pb2 as _options_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import resource_pb2 as _resource_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Ratelimit(_message.Message):
    __slots__ = ("name", "deployment", "account", "metric", "limit", "is_soft_limit", "reservation", "create_time", "update_time")
    NAME_FIELD_NUMBER: _ClassVar[int]
    DEPLOYMENT_FIELD_NUMBER: _ClassVar[int]
    ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    METRIC_FIELD_NUMBER: _ClassVar[int]
    LIMIT_FIELD_NUMBER: _ClassVar[int]
    IS_SOFT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    RESERVATION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    name: str
    deployment: str
    account: str
    metric: str
    limit: float
    is_soft_limit: bool
    reservation: float
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    def __init__(self, name: _Optional[str] = ..., deployment: _Optional[str] = ..., account: _Optional[str] = ..., metric: _Optional[str] = ..., limit: _Optional[float] = ..., is_soft_limit: bool = ..., reservation: _Optional[float] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/workload_shape.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/workload_shape.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import options_pb2 as gateway_dot_options__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgateway/workload_shape.proto\x12\x07gateway\x1a\x1b\x62uf/validate/validate.proto\x1a\x18gateway/deployment.proto\x1a\x15gateway/options.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe3\r\n\rWorkloadShape\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x19\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x35\n\x0bupdate_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12+\n\ncreated_by\x18\x06 \x01(\tB\x17\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x0c\x12\nOWNER_ONLY\x12X\n\x0b\x61nnotations\x18\x07 \x03(\x0b\x32\'.gateway.WorkloadShape.AnnotationsEntryB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x19\n\nbase_model\x18\x08 \x01(\tB\x05\xe2\x41\x02\x02\x05\x12&\n\x11\x61\x63\x63\x65lerator_count\x18\t \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x38\n\x10\x61\x63\x63\x65lerator_type\x18\n \x01(\x0e\x32\x18.gateway.AcceleratorTypeB\x04\xe2\x41\x01\x01\x12\x36\n\tprecision\x18\x0b \x01(\x0e\x32\x1d.gateway.Deployment.PrecisionB\x04\xe2\x41\x01\x01\x12\x35\n\nworld_size\x18\x0c \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12:\n\x0fgenerator_count\x18\r \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12H\n\x1b\x64isaggregated_prefill_count\x18\x0e \x01(\x05\x42#\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18\x10(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12K\n disaggregated_prefill_world_size\x18\x0f \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12<\n\x0emax_batch_size\x18\x10 \x01(\x05\x42$\xe2\x41\x01\x01\xbaH\x07\x1a\x05\x18\x80\x08(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x1f\n\renable_addons\x18\x11 \x01(\x08\x42\x08\xe2\x41\x01\x01\xa8\xf1\x04\x01\x12&\n\x11\x64raft_token_count\x18\x12 \x01(\x05\x42\x0b\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\x12\x19\n\x0b\x64raft_model\x18\x13 \x01(\tB\x04\xe2\x41\x01\x01\x12&\n\x18ngram_speculation_length\x18\x14 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12>\n\x13max_lora_batch_size\x18\x15 \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12@\n\x13kv_cache_memory_pct\x18\x16 \x01(\x05\x42#\xe2\x41\x01\x01\xbaH\x06\x1a\x04\x18Z(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12%\n\x17\x65nable_session_affinity\x18\x17 \x01(\x08\x42\x04\xe2\x41\x01\x01\x12-\n\timage_tag\x18\x18 \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12+\n\x16num_lora_device_cached\x18\x19 \x01(\x05\x42\x0b\xe2\x41\x01\x03\xbaH\x04\x1a\x02(\x00\x12.\n\nextra_args\x18\x1a \x03(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12=\n\x12max_context_length\x18\x1b \x01(\x05\x42!\xe2\x41\x01\x01\xbaH\x04\x1a\x02(\x00\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12Y\n\x0c\x65xtra_values\x18\x1c \x03(\x0b\x32\'.gateway.WorkloadShape.ExtraValuesEntryB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12G\n\x06\x65ngine\x18\x1d \x01(\x0e\x32\x1a.gateway.Deployment.EngineB\x1b\xe2\x41\x02\x01\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x32\n\x10\x45xtraValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01:\x86\x01\xea\x41v\n\x1e\x61pi.fireworks.ai/WorkloadShape\x12\x35\x61\x63\x63ounts/{AccountId}/workloadShapes/{WorkloadShapeId}*\x0eworkloadShapes2\rworkloadShape\x82\xf1\x04\t\n\x07\x41\x63\x63ount\"\xb0\x01\n\x1a\x43reateWorkloadShapeRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\x0eworkload_shape\x18\x02 \x01(\x0b\x32\x16.gateway.WorkloadShapeB\x04\xe2\x41\x01\x02\x12\x1f\n\x11workload_shape_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12%\n\x17\x64isable_size_validation\x18\x04 \x01(\x08\x42\x04\xe2\x41\x01\x01\"b\n\x17GetWorkloadShapeRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x33\n\tread_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\xc7\x01\n\x19ListWorkloadShapesRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x33\n\tread_mask\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"z\n\x1aListWorkloadShapesResponse\x12/\n\x0fworkload_shapes\x18\x01 \x03(\x0b\x32\x16.gateway.WorkloadShape\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"\xb0\x01\n\x1aUpdateWorkloadShapeRequest\x12\x34\n\x0eworkload_shape\x18\x01 \x01(\x0b\x32\x16.gateway.WorkloadShapeB\x04\xe2\x41\x01\x02\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\x12%\n\x17\x64isable_size_validation\x18\x03 \x01(\x08\x42\x04\xe2\x41\x01\x01\"0\n\x1a\x44\x65leteWorkloadShapeRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.workload_shape_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_WORKLOADSHAPE_ANNOTATIONSENTRY']._loaded_options = None
  _globals['_WORKLOADSHAPE_ANNOTATIONSENTRY']._serialized_options = b'8\001'
  _globals['_WORKLOADSHAPE_EXTRAVALUESENTRY']._loaded_options = None
  _globals['_WORKLOADSHAPE_EXTRAVALUESENTRY']._serialized_options = b'8\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['name']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOADSHAPE'].fields_by_name['display_name']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['description']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['description']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['create_time']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_WORKLOADSHAPE'].fields_by_name['update_time']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_WORKLOADSHAPE'].fields_by_name['created_by']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\014\022\nOWNER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['annotations']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['annotations']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['base_model']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['base_model']._serialized_options = b'\342A\002\002\005'
  _globals['_WORKLOADSHAPE'].fields_by_name['accelerator_count']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['accelerator_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_WORKLOADSHAPE'].fields_by_name['accelerator_type']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['accelerator_type']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['precision']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['precision']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['world_size']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['world_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['generator_count']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['generator_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['disaggregated_prefill_count']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['disaggregated_prefill_count']._serialized_options = b'\342A\001\001\272H\006\032\004\030\020(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['disaggregated_prefill_world_size']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['disaggregated_prefill_world_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['max_batch_size']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['max_batch_size']._serialized_options = b'\342A\001\001\272H\007\032\005\030\200\010(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['enable_addons']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['enable_addons']._serialized_options = b'\342A\001\001\250\361\004\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['draft_token_count']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['draft_token_count']._serialized_options = b'\342A\001\001\272H\004\032\002(\000'
  _globals['_WORKLOADSHAPE'].fields_by_name['draft_model']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['draft_model']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['ngram_speculation_length']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['ngram_speculation_length']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['max_lora_batch_size']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['max_lora_batch_size']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['kv_cache_memory_pct']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['kv_cache_memory_pct']._serialized_options = b'\342A\001\001\272H\006\032\004\030Z(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['enable_session_affinity']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['enable_session_affinity']._serialized_options = b'\342A\001\001'
  _globals['_WORKLOADSHAPE'].fields_by_name['image_tag']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['image_tag']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['num_lora_device_cached']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['num_lora_device_cached']._serialized_options = b'\342A\001\003\272H\004\032\002(\000'
  _globals['_WORKLOADSHAPE'].fields_by_name['extra_args']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['extra_args']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['max_context_length']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['max_context_length']._serialized_options = b'\342A\001\001\272H\004\032\002(\000\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['extra_values']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['extra_values']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE'].fields_by_name['engine']._loaded_options = None
  _globals['_WORKLOADSHAPE'].fields_by_name['engine']._serialized_options = b'\342A\002\001\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_WORKLOADSHAPE']._loaded_options = None
  _globals['_WORKLOADSHAPE']._serialized_options = b'\352Av\n\036api.fireworks.ai/WorkloadShape\0225accounts/{AccountId}/workloadShapes/{WorkloadShapeId}*\016workloadShapes2\rworkloadShape\202\361\004\t\n\007Account'
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape']._loaded_options = None
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape']._serialized_options = b'\342A\001\002'
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape_id']._loaded_options = None
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape_id']._serialized_options = b'\342A\001\001'
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['disable_size_validation']._loaded_options = None
  _globals['_CREATEWORKLOADSHAPEREQUEST'].fields_by_name['disable_size_validation']._serialized_options = b'\342A\001\001'
  _globals['_GETWORKLOADSHAPEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETWORKLOADSHAPEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETWORKLOADSHAPEREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_GETWORKLOADSHAPEREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_LISTWORKLOADSHAPESREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape']._loaded_options = None
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['workload_shape']._serialized_options = b'\342A\001\002'
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['update_mask']._loaded_options = None
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['update_mask']._serialized_options = b'\342A\001\001'
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['disable_size_validation']._loaded_options = None
  _globals['_UPDATEWORKLOADSHAPEREQUEST'].fields_by_name['disable_size_validation']._serialized_options = b'\342A\001\001'
  _globals['_DELETEWORKLOADSHAPEREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEWORKLOADSHAPEREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_WORKLOADSHAPE']._serialized_start=276
  _globals['_WORKLOADSHAPE']._serialized_end=2039
  _globals['_WORKLOADSHAPE_ANNOTATIONSENTRY']._serialized_start=1800
  _globals['_WORKLOADSHAPE_ANNOTATIONSENTRY']._serialized_end=1850
  _globals['_WORKLOADSHAPE_EXTRAVALUESENTRY']._serialized_start=1852
  _globals['_WORKLOADSHAPE_EXTRAVALUESENTRY']._serialized_end=1902
  _globals['_CREATEWORKLOADSHAPEREQUEST']._serialized_start=2042
  _globals['_CREATEWORKLOADSHAPEREQUEST']._serialized_end=2218
  _globals['_GETWORKLOADSHAPEREQUEST']._serialized_start=2220
  _globals['_GETWORKLOADSHAPEREQUEST']._serialized_end=2318
  _globals['_LISTWORKLOADSHAPESREQUEST']._serialized_start=2321
  _globals['_LISTWORKLOADSHAPESREQUEST']._serialized_end=2520
  _globals['_LISTWORKLOADSHAPESRESPONSE']._serialized_start=2522
  _globals['_LISTWORKLOADSHAPESRESPONSE']._serialized_end=2644
  _globals['_UPDATEWORKLOADSHAPEREQUEST']._serialized_start=2647
  _globals['_UPDATEWORKLOADSHAPEREQUEST']._serialized_end=2823
  _globals['_DELETEWORKLOADSHAPEREQUEST']._serialized_start=2825
  _globals['_DELETEWORKLOADSHAPEREQUEST']._serialized_end=2873
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/evaluation_job.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/evaluation_job.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import deployment_pb2 as gateway_dot_deployment__pb2
from . import job_progress_pb2 as gateway_dot_job__progress__pb2
from . import options_pb2 as gateway_dot_options__pb2
from . import status_pb2 as gateway_dot_status__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgateway/evaluation_job.proto\x12\x07gateway\x1a\x18gateway/deployment.proto\x1a\x1agateway/job_progress.proto\x1a\x15gateway/options.proto\x1a\x14gateway/status.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/api/visibility.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x91\x07\n\rEvaluationJob\x12\x13\n\x04name\x18\x01 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\x1a\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x04\xe2\x41\x01\x01\x12\x36\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x05\xe2\x41\x02\x03\x05\x12\x19\n\ncreated_by\x18\x04 \x01(\tB\x05\xe2\x41\x02\x03\x05\x12\'\n\x05state\x18\x05 \x01(\x0e\x32\x11.gateway.JobStateB\x05\xe2\x41\x02\x03\x05\x12&\n\x06status\x18\x06 \x01(\x0b\x32\x0f.gateway.StatusB\x05\xe2\x41\x02\x03\x05\x12\x17\n\tevaluator\x18\x07 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1b\n\rinput_dataset\x18\x08 \x01(\tB\x04\xe2\x41\x01\x02\x12\x1c\n\x0eoutput_dataset\x18\n \x01(\tB\x04\xe2\x41\x01\x02\x12>\n\x07metrics\x18\t \x03(\x0b\x32#.gateway.EvaluationJob.MetricsEntryB\x08\xe2\x41\x01\x03\xa0\xf1\x04\x01\x12\x1a\n\x0coutput_stats\x18\x0c \x01(\tB\x04\xe2\x41\x01\x05\x12\x35\n\x0bupdate_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03\x12\x46\n\"reinforcement_fine_tuning_epoch_id\x18\r \x01(\tB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12;\n\x17skip_dataset_validation\x18\x0e \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12G\n\x0cjob_progress\x18\x0f \x01(\x0b\x32\x14.gateway.JobProgressB\x1b\xe2\x41\x02\x03\x05\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12;\n\x06region\x18\x10 \x01(\x0e\x32\x0f.gateway.RegionB\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x1a.\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x01:\x02\x38\x01:\x88\x01\xea\x41v\n\x1e\x61pi.fireworks.ai/EvaluationJob\x12\x35\x61\x63\x63ounts/{AccountId}/evaluationJobs/{EvaluationJobId}*\x0e\x45valuationJobs2\rEvaluationJob\x82\xf1\x04\x0b\n\x07\x41\x63\x63ount\x18\x01\"b\n\x17GetEvaluationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x33\n\tread_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"\x89\x01\n\x1a\x43reateEvaluationJobRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x34\n\x0e\x65valuation_job\x18\x02 \x01(\x0b\x32\x16.gateway.EvaluationJobB\x04\xe2\x41\x01\x02\x12\x1f\n\x11\x65valuation_job_id\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\"\xfa\x01\n\x19ListEvaluationJobsRequest\x12\x14\n\x06parent\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x12\x17\n\tpage_size\x18\x02 \x01(\x05\x42\x04\xe2\x41\x01\x01\x12\x18\n\npage_token\x18\x03 \x01(\tB\x04\xe2\x41\x01\x01\x12\x14\n\x06\x66ilter\x18\x04 \x01(\tB\x04\xe2\x41\x01\x01\x12\x16\n\x08order_by\x18\x05 \x01(\tB\x04\xe2\x41\x01\x01\x12\x31\n\rshow_internal\x18\x06 \x01(\x08\x42\x1a\xe2\x41\x01\x01\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x33\n\tread_mask\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe2\x41\x01\x01\"z\n\x1aListEvaluationJobsResponse\x12/\n\x0f\x65valuation_jobs\x18\x01 \x03(\x0b\x32\x16.gateway.EvaluationJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x12\n\ntotal_size\x18\x03 \x01(\x05\"0\n\x1a\x44\x65leteEvaluationJobRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe2\x41\x01\x02\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.evaluation_job_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_EVALUATIONJOB_METRICSENTRY']._loaded_options = None
  _globals['_EVALUATIONJOB_METRICSENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATIONJOB'].fields_by_name['name']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['name']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATIONJOB'].fields_by_name['display_name']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['display_name']._serialized_options = b'\342A\001\001'
  _globals['_EVALUATIONJOB'].fields_by_name['create_time']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['create_time']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATIONJOB'].fields_by_name['created_by']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['created_by']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATIONJOB'].fields_by_name['state']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['state']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATIONJOB'].fields_by_name['status']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['status']._serialized_options = b'\342A\002\003\005'
  _globals['_EVALUATIONJOB'].fields_by_name['evaluator']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['evaluator']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATIONJOB'].fields_by_name['input_dataset']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['input_dataset']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATIONJOB'].fields_by_name['output_dataset']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['output_dataset']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATIONJOB'].fields_by_name['metrics']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['metrics']._serialized_options = b'\342A\001\003\240\361\004\001'
  _globals['_EVALUATIONJOB'].fields_by_name['output_stats']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['output_stats']._serialized_options = b'\342A\001\005'
  _globals['_EVALUATIONJOB'].fields_by_name['update_time']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['update_time']._serialized_options = b'\342A\001\003'
  _globals['_EVALUATIONJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['reinforcement_fine_tuning_epoch_id']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EVALUATIONJOB'].fields_by_name['skip_dataset_validation']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['skip_dataset_validation']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EVALUATIONJOB'].fields_by_name['job_progress']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['job_progress']._serialized_options = b'\342A\002\003\005\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EVALUATIONJOB'].fields_by_name['region']._loaded_options = None
  _globals['_EVALUATIONJOB'].fields_by_name['region']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_EVALUATIONJOB']._loaded_options = None
  _globals['_EVALUATIONJOB']._serialized_options = b'\352Av\n\036api.fireworks.ai/EvaluationJob\0225accounts/{AccountId}/evaluationJobs/{EvaluationJobId}*\016EvaluationJobs2\rEvaluationJob\202\361\004\013\n\007Account\030\001'
  _globals['_GETEVALUATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_GETEVALUATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_GETEVALUATIONJOBREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_GETEVALUATIONJOBREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['evaluation_job']._loaded_options = None
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['evaluation_job']._serialized_options = b'\342A\001\002'
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['evaluation_job_id']._loaded_options = None
  _globals['_CREATEEVALUATIONJOBREQUEST'].fields_by_name['evaluation_job_id']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['parent']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['parent']._serialized_options = b'\342A\001\002'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['page_size']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['page_token']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['filter']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['order_by']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['order_by']._serialized_options = b'\342A\001\001'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['show_internal']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['show_internal']._serialized_options = b'\342A\001\001\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['read_mask']._loaded_options = None
  _globals['_LISTEVALUATIONJOBSREQUEST'].fields_by_name['read_mask']._serialized_options = b'\342A\001\001'
  _globals['_DELETEEVALUATIONJOBREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_DELETEEVALUATIONJOBREQUEST'].fields_by_name['name']._serialized_options = b'\342A\001\002'
  _globals['_EVALUATIONJOB']._serialized_start=297
  _globals['_EVALUATIONJOB']._serialized_end=1210
  _globals['_EVALUATIONJOB_METRICSENTRY']._serialized_start=1025
  _globals['_EVALUATIONJOB_METRICSENTRY']._serialized_end=1071
  _globals['_GETEVALUATIONJOBREQUEST']._serialized_start=1212
  _globals['_GETEVALUATIONJOBREQUEST']._serialized_end=1310
  _globals['_CREATEEVALUATIONJOBREQUEST']._serialized_start=1313
  _globals['_CREATEEVALUATIONJOBREQUEST']._serialized_end=1450
  _globals['_LISTEVALUATIONJOBSREQUEST']._serialized_start=1453
  _globals['_LISTEVALUATIONJOBSREQUEST']._serialized_end=1703
  _globals['_LISTEVALUATIONJOBSRESPONSE']._serialized_start=1705
  _globals['_LISTEVALUATIONJOBSRESPONSE']._serialized_end=1827
  _globals['_DELETEEVALUATIONJOBREQUEST']._serialized_start=1829
  _globals['_DELETEEVALUATIONJOBREQUEST']._serialized_end=1877
# @@protoc_insertion_point(module_scope)



from ..buf.validate import validate_pb2 as _validate_pb2
from . import options_pb2 as _options_pb2
from . import status_pb2 as _status_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.api import resource_pb2 as _resource_pb2
from google.api import visibility_pb2 as _visibility_pb2
from google.protobuf import field_mask_pb2 as _field_mask_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class McpServer(_message.Message):
    __slots__ = ("name", "display_name", "description", "create_time", "update_time", "endpoint_url", "api_key_secret", "simulated", "state", "status", "remote_hosted", "annotations", "public", "authentication_type", "featured")
    class AuthenticationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        AUTHENTICATION_TYPE_UNSPECIFIED: _ClassVar[McpServer.AuthenticationType]
        OPEN: _ClassVar[McpServer.AuthenticationType]
        API_KEY: _ClassVar[McpServer.AuthenticationType]
        OAUTH2: _ClassVar[McpServer.AuthenticationType]
        BEARER_TOKEN: _ClassVar[McpServer.AuthenticationType]
    AUTHENTICATION_TYPE_UNSPECIFIED: McpServer.AuthenticationType
    OPEN: McpServer.AuthenticationType
    API_KEY: McpServer.AuthenticationType
    OAUTH2: McpServer.AuthenticationType
    BEARER_TOKEN: McpServer.AuthenticationType
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        STATE_UNSPECIFIED: _ClassVar[McpServer.State]
        CREATING: _ClassVar[McpServer.State]
        ACTIVE: _ClassVar[McpServer.State]
        FAILED: _ClassVar[McpServer.State]
        DELETING: _ClassVar[McpServer.State]
    STATE_UNSPECIFIED: McpServer.State
    CREATING: McpServer.State
    ACTIVE: McpServer.State
    FAILED: McpServer.State
    DELETING: McpServer.State
    class AnnotationsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    DISPLAY_NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
    UPDATE_TIME_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_URL_FIELD_NUMBER: _ClassVar[int]
    API_KEY_SECRET_FIELD_NUMBER: _ClassVar[int]
    SIMULATED_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    REMOTE_HOSTED_FIELD_NUMBER: _ClassVar[int]
    ANNOTATIONS_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_FIELD_NUMBER: _ClassVar[int]
    AUTHENTICATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    FEATURED_FIELD_NUMBER: _ClassVar[int]
    name: str
    display_name: str
    description: str
    create_time: _timestamp_pb2.Timestamp
    update_time: _timestamp_pb2.Timestamp
    endpoint_url: str
    api_key_secret: str
    simulated: bool
    state: McpServer.State
    status: _status_pb2.Status
    remote_hosted: bool
    annotations: _containers.ScalarMap[str, str]
    public: bool
    authentication_type: McpServer.AuthenticationType
    featured: bool
    def __init__(self, name: _Optional[str] = ..., display_name: _Optional[str] = ..., description: _Optional[str] = ..., create_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., update_time: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., endpoint_url: _Optional[str] = ..., api_key_secret: _Optional[str] = ..., simulated: bool = ..., state: _Optional[_Union[McpServer.State, str]] = ..., status: _Optional[_Union[_status_pb2.Status, _Mapping]] = ..., remote_hosted: bool = ..., annotations: _Optional[_Mapping[str, str]] = ..., public: bool = ..., authentication_type: _Optional[_Union[McpServer.AuthenticationType, str]] = ..., featured: bool = ...) -> None: ...

class CreateMcpServerRequest(_message.Message):
    __slots__ = ("parent", "mcp_server", "mcp_server_id")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    MCP_SERVER_FIELD_NUMBER: _ClassVar[int]
    MCP_SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    parent: str
    mcp_server: McpServer
    mcp_server_id: str
    def __init__(self, parent: _Optional[str] = ..., mcp_server: _Optional[_Union[McpServer, _Mapping]] = ..., mcp_server_id: _Optional[str] = ...) -> None: ...

class GetMcpServerRequest(_message.Message):
    __slots__ = ("name", "read_mask")
    NAME_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    name: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, name: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ListMcpServersRequest(_message.Message):
    __slots__ = ("parent", "page_size", "page_token", "filter", "order_by", "read_mask")
    PARENT_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    ORDER_BY_FIELD_NUMBER: _ClassVar[int]
    READ_MASK_FIELD_NUMBER: _ClassVar[int]
    parent: str
    page_size: int
    page_token: str
    filter: str
    order_by: str
    read_mask: _field_mask_pb2.FieldMask
    def __init__(self, parent: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., filter: _Optional[str] = ..., order_by: _Optional[str] = ..., read_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class ListMcpServersResponse(_message.Message):
    __slots__ = ("mcp_servers", "next_page_token", "total_size")
    MCP_SERVERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOTAL_SIZE_FIELD_NUMBER: _ClassVar[int]
    mcp_servers: _containers.RepeatedCompositeFieldContainer[McpServer]
    next_page_token: str
    total_size: int
    def __init__(self, mcp_servers: _Optional[_Iterable[_Union[McpServer, _Mapping]]] = ..., next_page_token: _Optional[str] = ..., total_size: _Optional[int] = ...) -> None: ...

class UpdateMcpServerRequest(_message.Message):
    __slots__ = ("mcp_server", "update_mask")
    MCP_SERVER_FIELD_NUMBER: _ClassVar[int]
    UPDATE_MASK_FIELD_NUMBER: _ClassVar[int]
    mcp_server: McpServer
    update_mask: _field_mask_pb2.FieldMask
    def __init__(self, mcp_server: _Optional[_Union[McpServer, _Mapping]] = ..., update_mask: _Optional[_Union[_field_mask_pb2.FieldMask, _Mapping]] = ...) -> None: ...

class DeleteMcpServerRequest(_message.Message):
    __slots__ = ("name",)
    NAME_FIELD_NUMBER: _ClassVar[int]
    name: str
    def __init__(self, name: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: gateway/job_progress.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'gateway/job_progress.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1agateway/job_progress.proto\x12\x07gateway\x1a\x1bgoogle/api/visibility.proto\"\x98\x02\n\x0bJobProgress\x12\x0f\n\x07percent\x18\x01 \x01(\x05\x12\r\n\x05\x65poch\x18\x02 \x01(\x05\x12%\n\x05\x63hunk\x18\x03 \x01(\x05\x42\x16\xfa\xd2\xe4\x93\x02\x10\x12\x0eSUPERUSER_ONLY\x12\x1c\n\x14total_input_requests\x18\x04 \x01(\x05\x12 \n\x18total_processed_requests\x18\x05 \x01(\x05\x12\'\n\x1fsuccessfully_processed_requests\x18\x06 \x01(\x05\x12\x17\n\x0f\x66\x61iled_requests\x18\x07 \x01(\x05\x12\x13\n\x0boutput_rows\x18\x08 \x01(\x05\x12\x14\n\x0cinput_tokens\x18\t \x01(\x05\x12\x15\n\routput_tokens\x18\n \x01(\x05\x42\x43ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gateway.job_progress_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZAgithub.com/fw-ai/fireworks/control_plane/protos/generated/gateway'
  _globals['_JOBPROGRESS'].fields_by_name['chunk']._loaded_options = None
  _globals['_JOBPROGRESS'].fields_by_name['chunk']._serialized_options = b'\372\322\344\223\002\020\022\016SUPERUSER_ONLY'
  _globals['_JOBPROGRESS']._serialized_start=69
  _globals['_JOBPROGRESS']._serialized_end=349
# @@protoc_insertion_point(module_scope)
